@@ -333,7 +333,7 @@ class ST_SignedTwipsMeasure(XsdInt):
     def convert_from_xml(cls, str_value):
         if 'i' in str_value or 'm' in str_value or 'p' in str_value:
             return ST_UniversalMeasure.convert_from_xml(str_value)
-        return Twips(int(str_value))
+        return Twips(round(float(str_value)))
 
     @classmethod
     def convert_to_xml(cls, value):
@@ -461,7 +461,12 @@ class ST_CoordOrigin(BaseSimpleType):
         if not str_value:
             return 0, 0
         values = str_value.split(',')
-        return int(values[0]) if values[0] else 0, int(values[1]) if values[1] else 0
+        if len(values) == 2:
+            return int(values[0]) if values[0] else 0, int(values[1]) if values[1] else 0
+        elif values[0]:
+            return int(values[0]), int(values[0])
+        else:
+            return 0, 0
 
     @classmethod
     def convert_to_xml(cls, value):
