@@ -17,6 +17,16 @@ class PictureShape(Parented):
     def rId(self):
         return self._pic.blipFill.blip.embed
 
+    @property
+    def has_wrap(self):
+        if hasattr(self.parent,'has_wrap'):
+            return self.parent.has_wrap
+        return None
+
+    @property
+    def parent(self):
+        return self._pic.parent
+
     @lazyproperty
     def parent_section(self):
         parent = self._pic.getparent()
